Name: festival
Version: 2.5
Release: 8%{?dist}
Summary: University of Edinburgh Speech Synthesis System

License: MIT
URL:            http://festvox.org
Source0: https://trycht.cz/festvox/packed/%{name}/%{version}/%{name}-%{version}.0-release.tar.gz
Source1: festival.scm
Source2: festival.service
# Use system wide speech_tools
Patch0: use_system_wide_speech_tools.patch
# Use system wide libraries for building and operations.
Patch1: use_system_libs.patch
# Fixes an ambiguity with an texi2html option.
Patch2: fix_doc_Makefile.patch
# Introduces site wide configuration in /etc.
Patch3: siteinit.patch
# Makes the system aware of the standard filesystem layout.
Patch4: filesystem-standard.patch

%{?systemd_ordering}
BuildRequires: speech-tools-libs-static texinfo gcc-c++ alsa-lib-devel ncurses-devel systemd
Requires(pre): shadow-utils

%description
Festival offers a general framework for building speech synthesis systems
as well as including examples of various modules. As a whole it offers full
text to speech through a number of APIs: from shell level,
through a Scheme command interpreter, as a C++ library, from Java, and an
Emacs interface.

%prep
%autosetup -n festival -p 0

%build
%configure
make CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" LIBDIR=%{_libdir}

%install
# Application files
mkdir -p %{buildroot}%{_bindir}
install -m 755 src/main/festival %{buildroot}%{_bindir}
install -m 755 src/main/festival_client %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/festival
install -m 644 lib/*.scm %{buildroot}%{_datadir}/festival
mkdir -p %{buildroot}%{_datadir}/festival/multisyn
install -m 644 lib/multisyn/*.scm %{buildroot}%{_datadir}/festival
mkdir -p %{buildroot}%{_datadir}/festival
install -m 644 lib/*gram* %{buildroot}%{_datadir}/festival
install -m 755 examples/text2wave %{buildroot}%{_bindir}
# Config
mkdir -p %{buildroot}%{_sysconfdir}
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
# Manual pages
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 doc/*.1 %{buildroot}%{_mandir}/man1
# For the dev subpackage
mkdir -p %{buildroot}%{_libdir}
install -m 644 src/lib/libFestival.a %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}/festival
install -m 644 src/include/*.h %{buildroot}%{_includedir}/festival

%files
%license COPYING
%doc README.md
%{_bindir}/*
%{_datadir}/*
%{_mandir}/man1/festival.1*
%{_mandir}/man1/festival_client.1*
%config(noreplace) %{_sysconfdir}/festival.scm
%{_unitdir}/festival.service

%pre
# Create festival's user and group
getent group festival >/dev/null || groupadd -r festival
getent passwd festival >/dev/null || \
    useradd -r -g festival -G audio -d %{_datadir}/festival -s /sbin/nologin \
    -c "User for running the festival server" festival

%post
%systemd_post festival.service

%preun
%systemd_preun festival.service

%postun
%systemd_postun festival.service

%package devel
Summary: Development files for festival

%description devel
This package contains the header files and the static library for festival.

%files devel
%{_includedir}/festival/*.h
%{_libdir}/libFestival.a

%changelog
* Tue Aug 28 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-8
- Use the new speech tools package naming.

* Tue Jul 17 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-7
- Correction of the changes in packaging of speech_tools.

* Fri May 18 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-6
- Fix the systemd unit, the server is not forking.

* Thu May 17 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com 2.5-5
- Drop support for f26 builds, remove the info files and the doc subpackage.

* Fri May 11 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-4
- Fix building on Fedora 26

* Thu May 10 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-3
- Add a basic systemd unit for the festival server.

* Wed May 9 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-2
- Add a default configuration file.

* Sat Apr 21 2018 Lukáš Tyrychtr <lukastyrychtr@gmail.com> 2.5-1
- Initial release

